#!/bin/bash
#
source /etc/conf.d/vdr.admin.cfg
source /etc/conf.d/vdr

# These plugins will be used after installation
DEFAULT_PLUGINS="mp3 mplayer dvd cdda epgsearch burn skinsoppalusikka admin "

SETVAL="sh /etc/vdr/plugins/admin/setadmval.sh"
KV="$(uname -r)"
KV_MAJOR=`uname -r | cut -f1 -d "."`
KV_MINOR=`uname -r | cut -f2 -d "."`

MODCONF="/etc/modules.autoload.d/kernel-${KV_MAJOR}.${KV_MINOR}"

set_xorg() {
   SCR_SET="    Screen "
   cat /etc/X11/xorg.conf.default | sed -e "s/$SCR_SET.*/$SCR_SET \"$1\"/" >  /etc/X11/xorg.conf
}

set_freevo() {
   sed -i /etc/freevo/freevo.conf -e "s/^geometry.*/geometry = $1/"
}

set_alsa() {
   ALSA_MOD="/etc/modules.d/alsa"
   sed -i $ALSA_MOD -e "/^alias snd-card-0.*/d"
   echo "" >> $ALSA_MOD
   echo "alias snd-card-0 $1" >> $ALSA_MOD
   echo "Updating modules ..."
   modules-update
   autoload $1
   $SETVAL "ALSA" 1
}

autoload() {
   LOADED=`cat $MODCONF | grep "^$*$"`
   if [ "$LOADED" = "" ] ; then
      echo "$*" >> $MODCONF
      echo "Adding $* to $MODCONF"
   else
      echo "$* is already in $MODCONF"
   fi
}

activate_plugin() {
   $SETVAL "PLG_$1" $2
}

test_directisa() {
   TEST_DATE="020200002002"
   hwclock --hctosys
   ACT_DATE=$(date +%m%d%H%M%Y.%S)
   date $TEST_DATE
   hwclock --systohc
   date $ACT_DATE
   hwclock --hctosys
   TD=$(date +%m%d%H%M%Y)
   date $ACT_DATE
   if [ "$TD" = "$TEST_DATE" ] ; then
      echo "RTC is working"
      DI=0
      hwclock --systohc
   else
      echo "directisa is necessary"   
      DI=1
   fi   
   $SETVAL "DIRECTISA_RTC" $DI
}

BOARD=$(/_config/bin/query_mb.sh)

rm -f /_config/bin/rvdrinit.sh

test_directisa
set_freevo "800x600"

perl /etc/vdr/plugins/admin/cfgplg.pl $DEFAULT_PLUGINS
sed -i /etc/freevo/local_conf.py -e "s/.*MPLAYER_VO_DEV.*/MPLAYER_VO_DEV = 'x11'/"
sed -i /etc/freevo/local_conf.py -e "s/.*XINE_VO_DEV.*/XINE_VO_DEV = 'xshm'/"
$SETVAL GUI Aus
$SETVAL LIRC ALDI4689-336
$SETVAL FRITZWATCH 0

sed -i $MODCONF -e "/^natsemi/d"
rc-update del activylircd boot >/dev/null 2>&1
$SETVAL WATCHDOG 60
$SETVAL SHUTDOWN_METHOD Halt
$SETVAL WAKEUP_METHOD ACPI
$SETVAL GUI_SWITCH_OUTPUT 0
$SETVAL GUI_LOOP_OUTPUT 0
$SETVAL ACPI 1


case "$BOARD" in
   MP_*)
#      set_alsa "snd-ens1371"
#      set_alsa "snd-es1938"
      $SETVAL MP_TVOUT 0
      $SETVAL WAKEUP_METHOD NVRAM
      $SETVAL SHUTDOWN_METHOD PowerOffKernel
      $SETVAL NVRAM_BOARD $BOARD
      $SETVAL ACPI 0
      echo "sh /_config/bin/mpkeys.sh" > /_config/bin/rvdrinit.sh
      chmod +x /_config/bin/rvdrinit.sh
      #$SETVAL "GUI" "FreeVo"
      set_xorg "ScrMP"
      ;;
   EPIA_M)
#      set_alsa "snd-via82xx"
      $SETVAL WAKEUP_METHOD NVRAM
      $SETVAL ACPI 1
      set_xorg "ScrVia"
      ;;
   ACTIVY)
      $SETVAL WAKEUP_METHOD ACPI
      rc-update del lircd boot
      rc-update add activylircd boot
      rc-update add irexec default
      $SETVAL ACPI 1
      $SETVAL LIRC Tastatur
      $SETVAL GUI FreeVo
      autoload "i2c-dev"
      autoload "i2c-i801"
      autoload "natsemi"
      modprobe natsemi
#      set_alsa "snd-intel8x0"
      set_xorg "ScrActivy"
      set_freevo "720x576"
      sed -i /etc/freevo/local_conf.py -e "s/.*MPLAYER_VO_DEV.*/MPLAYER_VO_DEV = 'xv'/"
      sed -i /etc/freevo/local_conf.py -e "s/.*XINE_VO_DEV.*/XINE_VO_DEV = 'xv'/"
      activate_plugin "alcd" "1"
      activate_plugin "dvd" "0"
      ;;
   *)
      echo "Unknown Board - Autoconfiguring X"
      sh /_config/bin/detect_x.sh
      ;;
esac

echo "Checking for ALSA ..."
sh /_config/bin/alsaconf_auto.sh
if [ $? = 99 ] ; then
   $SETVAL "ALSA" 1
   /etc/init.d/alsasound stop
else
   $SETVAL "ALSA" 0
fi   
