#!/bin/sh

set -x

# Variables passed in:
# $RECORDING_PATH           Path of VDR recording (/video0/%Bla/2004-01-...rec)
# $MPEG_PATH                Path where streams and movie are stored
# $VIDEO_FILE               Full path- and filename of demuxed video stream
# $AUDIO_FILES              Space-separated list of demuxed audio streams
# $MOVIE_FILE               Full path- and filename of muxed movie
# $REQUANT_FACTOR           Factor by that video shall be shrinked
# $IGNORE_TRACKS            Comma-separated list of audio track IDs to be 
#                           ignored
# $DVDAUTHOR_XML            Full path- and filename of the DVDAuthor XML
# $DVDAUTHOR_PATH           Full path of the written DVD structure
# $ISO_FILE                 Full path- and filename of target ISO
# $ISO_PIPE                 Fifo where the created ISO should be piped into
# $DVD_DEVICE               Full path- and filename of the DVD burner device

case $1 in
	render)
		# XXX TODO !!!!
		png2yuv -j $MENU_BACKGROUND -f 25 -n 1 -I t -L 1 | \
		mpeg2enc -f 8 -n p -o /tmp/vdrburn-menu-bg.m2v
		mplex -f 8 -o /dev/stdout /tmp/vdrburn-menu-bg.m2v $MENU_SOUNDTRACK | \
		spumux -v 2 $MENU_XML > $MENU_MPEG
	;;

	demux)
		REQUANTCMD=""
		if [ ! -z $REQUANT_FACTOR ]; then
			REQUANTCMD="requant $REQUANT_FACTOR |"
		fi

		IGNORE=""
		if [ ! -z $IGNORE_TRACKS ]; then
			IGNORE="-ignore $IGNORE_TRACKS"
		fi

		vdrsync.pl -o $MPEG_PATH \
			-v-filter "$REQUANTCMD burn-buffers > vdrsync.mpv" \
			-a-filter "burn-buffers > vdrsync%%d.mpa" \
			-ac3-filter "burn-buffers > vdrsync%%d.ac3" \
			$IGNORE "$RECORDING_PATH"
	;;

	mplex)
		mplex -f 8 -o $MOVIE_FILE $VIDEO_FILE $AUDIO_FILES
	;;

	author)
		dvdauthor -x $DVDAUTHOR_XML
	;;

	mkiso)
		mkisofs -dvd-video $DVDAUTHOR_PATH >"$ISO_FILE"
	;;

	burndir)
		growisofs -use-the-force-luke=tty -dvd-compat -Z $DVD_DEVICE \
				  -dvd-video $DVDAUTHOR_PATH
	;;

	pipeiso)
		mkifofs -dvd-video $DVDAUTHOR_PATH | tee "$ISO_FILE" > $ISO_PIPE
	;;

	burniso)
		growisofs -use-the-force-luke=tty -dvd-compat -Z $DVD_DEVICE=$ISO_PIPE
	;;

	*)
		echo "Usage: $0 {demux}"
		exit 1
	;;
esac

exit $?
