#!/bin/sh
# set -x

# Edit this path's / settings
# ===========================
#
# where is VDR's config-directory
CONFIGPATH="/etc/vdr"
#
# defines if the patch text2skin_extensions is installed ("true" or "false")
T2S_EXT="true"
#
# defines if the switchonly-patch by LightYear is installed ("true" or "false")
#SW_ONLY="false" # not supported yet
#
# delay for marquee-text [ms]
MARQUEE_DELAY="50"
#
# define the min. available disk space for the warning 'low disk space' [h]
MIN_DISK_SPACE="5"
#
# defines scrolling ('marquee'- or 'text'-token, true or false)
SCROLL_MENU_TITLE="true" # title in all menus
SCROLL_MAINMENU_ITEM="false" # menu-items in the main-menu
SCROLL_SUBMENU_ITEM="true" # menu-items in the sub-menus
SCROLL_SIDEBAR_ITEM="false" # timer-titles on the sidebar
SCROLL_REPLAY_TITLE="true"  # title on the replay-status-info
SCROLL_EPG_TITLE="true" # title and so on in extedned EPG-info
SCROLL_RECINFO_TITLE="true" # title and so on in recording-info
#
# defines, if the date/time is shown in the small info-screens
# (all except menu: like channel-info, replay-info, audio-selection ...)
SHOW_DATETIME="true"
#
# define, if you want to see a '+' in front of the the seperators in the menues
# (this looks nice e.g. in the channels-menu but not so nice in some plugins)
SHOW_SEPERATOR_PLUS="false"
#
# Green-mode: deactivates viewing the size of a recording which keeps disks from
# spinning up (if you have your recordings distributed on several disks)
GREEN_MODE="false"
#
# imprint tux on the sidebar; for the tux-lovers out there ;-)
# ("true" or "false")
IMPRINT_TUX="false"
#



# Don't edit beyond here
# ======================

SKINPATH="$CONFIGPATH/plugins/text2skin/Enigma"
SKINTHEMEPATH="$CONFIGPATH/themes"
SKIN_TEMPLATE="$SKINPATH/Enigma.skin.template"
SKIN_TMP="$SKINPATH/Enigma.skin.tmp"

SKIN="$SKINPATH/Enigma.skin"
ENIGMA_THEME="Enigma-default.theme"
DARKBLUE_THEME="Enigma-DarkBlue.theme"
SETUP="$CONFIGPATH/setup.conf"

# check for config file
[ ! -e $SETUP ] && printf "\nERROR: CONFIGPATH not set correctly - please edit this script\n\n" && exit 1

printf "\nCreating Enigma Skin ($SKIN)\n"

# default
w_def=600

w=`grep "^OSDWidth " $SETUP | awk 'BEGIN{FS="=";}{print $2;}'`
[ -z $w ] && w=$w_def

#echo "W -> $w"

button_dist=2
button_width=`expr \( $w - 3 \* $button_dist \) \/ 4`
rest=`expr $w - \( 4 \* $button_width + 3 \* $button_dist \)`
#echo "B -> $button_width, rest -> $rest"

r_l=0
r_r=`expr $button_width - 1`
g_l=`expr $r_l + $button_width + $button_dist`
g_r=`expr $r_r + $button_width + $button_dist + $rest \/ 2`
y_l=`expr $g_l + $button_width + $button_dist`
y_r=`expr $g_r + $button_width + $button_dist`
b_l=`expr $y_l + $button_width + $button_dist`
b_r=-1

#echo "r_l -> $r_l, r_r -> $r_r"
#echo "g_l -> $g_l, g_r -> $g_r"
#echo "y_l -> $y_l, y_r -> $y_r"
#echo "b_l -> $b_l, b_r -> $b_r"

disk_warn_level=`expr $MIN_DISK_SPACE \* 60 \* 2575 \/ 100`

if [ "$SCROLL_MENU_TITLE" = "true" ] ; then
	TK_MENU_TITLE="marquee"
else
	TK_MENU_TITLE="text"
fi

if [ "$SCROLL_MAINMENU_ITEM" = "true" ] ; then
	TK_MAINMENU_ITEM="marquee"
else
	TK_MAINMENU_ITEM="text"
fi

if [ "$SCROLL_SUBMENU_ITEM" = "true" ] ; then
	TK_SUBMENU_ITEM="marquee"
else
	TK_SUBMENU_ITEM="text"
fi

if [ "$SCROLL_SIDEBAR_ITEM" = "true" ] ; then
	TK_SIDEBAR_ITEM="marquee"
else
	TK_SIDEBAR_ITEM="text"
fi

if [ "$SCROLL_REPLAY_TITLE" = "true" ] ; then
	TK_REPLAY_TITLE="marquee"
else
	TK_REPLAY_TITLE="text"
fi

if [ "$SCROLL_EPG_TITLE" = "true" ] ; then
	TK_EPG_TITLE="marquee"
else
	TK_EPG_TITLE="text"
fi

if [ "$SCROLL_RECINFO_TITLE" = "true" ] ; then
	TK_RECINFO_TITLE="marquee"
else
	TK_RECINFO_TITLE="text"
fi

if [ "$SHOW_DATETIME" = "true" ] ; then
	show_datetime=1
else
	show_datetime=0
fi

if [ "$SHOW_SEPERATOR_PLUS" = "true" ] ; then
	show_seperator_plus=1
else
	show_seperator_plus=0
fi

if [ "$IMPRINT_TUX" = "true" ] ; then
	tux=1
else
	tux=0
fi

if [ "$GREEN_MODE" = "true" ] ; then
	green_mode=1
else
	green_mode=0
fi


# substitute
cat $SKIN_TEMPLATE \
| sed -e "s/%RED_L%/"$r_l"/g" \
| sed -e "s/%RED_L_T%/"`expr $r_l + 0`"/g" \
| sed -e "s/%RED_L_P1%/"`expr $r_l + 1`"/g" \
| sed -e "s/%RED_R%/"$r_r"/g" \
| sed -e "s/%RED_R_T%/"`expr $r_r + $button_dist`"/g" \
| sed -e "s/%RED_R_M1%/"`expr $r_r - 1`"/g" \
| sed -e "s/%GREEN_L%/"$g_l"/g" \
| sed -e "s/%GREEN_L_T%/"`expr $g_l - $button_dist`"/g" \
| sed -e "s/%GREEN_L_P1%/"`expr $g_l + 1`"/g" \
| sed -e "s/%GREEN_R%/"$g_r"/g" \
| sed -e "s/%GREEN_R_T%/"`expr $g_r + $button_dist`"/g" \
| sed -e "s/%GREEN_R_M1%/"`expr $g_r - 1`"/g" \
| sed -e "s/%YELLOW_L%/"$y_l"/g" \
| sed -e "s/%YELLOW_L_T%/"`expr $y_l - $button_dist`"/g" \
| sed -e "s/%YELLOW_L_P1%/"`expr $y_l + 1`"/g" \
| sed -e "s/%YELLOW_R%/"$y_r"/g" \
| sed -e "s/%YELLOW_R_T%/"`expr $y_r + $button_dist`"/g" \
| sed -e "s/%YELLOW_R_M1%/"`expr $y_r - 1`"/g" \
| sed -e "s/%BLUE_L%/"$b_l"/g" \
| sed -e "s/%BLUE_L_T%/"`expr $b_l - $button_dist`"/g" \
| sed -e "s/%BLUE_L_P1%/"`expr $b_l + 1`"/g" \
| sed -e "s/%BLUE_R%/"$b_r"/g" \
| sed -e "s/%BLUE_R_T%/"`expr $b_r + 0`"/g" \
| sed -e "s/%BLUE_R_M1%/"`expr $b_r - 1`"/g" \
| sed -e "s/%MIN_DISK_SPACE%/"$disk_warn_level"/g" \
| sed -e "s/%MARQUEE_DELAY%/"$MARQUEE_DELAY"/g" \
| sed -e "s/%TK_MENU_TITLE%/"$TK_MENU_TITLE"/g" \
| sed -e "s/%TK_MAINMENU_ITEM%/"$TK_MAINMENU_ITEM"/g" \
| sed -e "s/%TK_SUBMENU_ITEM%/"$TK_SUBMENU_ITEM"/g" \
| sed -e "s/%TK_SIDEBAR_ITEM%/"$TK_SIDEBAR_ITEM"/g" \
| sed -e "s/%TK_REPLAY_TITLE%/"$TK_REPLAY_TITLE"/g" \
| sed -e "s/%TK_EPG_TITLE%/"$TK_EPG_TITLE"/g" \
| sed -e "s/%TK_RECINFO_TITLE%/"$TK_RECINFO_TITLE"/g" \
| sed -e "s/%SHOW_DATETIME%/"$show_datetime"/g" \
| sed -e "s/%SHOW_SEPERATOR_PLUS%/"$show_seperator_plus"/g" \
| sed -e "s/%TUX%/"$tux"/g" \
| sed -e "s/%GREEN_MODE%/"$green_mode"/g" \
> $SKIN_TMP

if [ "$T2S_EXT" = "true" ] ; then
	sed -re 's/^EXT(.*)$/	\1/g' $SKIN_TMP | grep -v "^!EXT" > $SKIN
else
	sed -re 's/^!EXT(.*)$/	\1/g' $SKIN_TMP | grep -v "^EXT" > $SKIN
fi

rm $SKIN_TMP

# Remove old Themes
printf "\nRemove old Theme files\n"
[ -f $SKINTHEMEPATH/$ENIGMA_THEME ] \
&& rm -f $SKINTHEMEPATH/$ENIGMA_THEME

[ -f $SKINTHEMEPATH/$DARKBLUE_THEME ] \
&& rm -f $SKINTHEMEPATH/$DARKBLUE_THEME

printf "\nCopying DarkBlue Theme file\n($ENIGMA_THEME is created when VDR is started)\n"
cp $SKINPATH/themes/$DARKBLUE_THEME $SKINTHEMEPATH

exit 0
